from flask import current_app

from init import db
from shopyo_settings.models import Settings


def add_setting(name, value):
    if Settings.query.filter_by(setting=name).first():
        s = Settings.query.get(name)
        s.value = value
        db.session.commit()
    else:
        s = Settings(setting=name, value=value)
        db.session.add(s)
        db.session.commit()


def upload(verbose=False):
    for name, value in current_app.config["SEED_SETTINGS"].items():
        add_setting(name, value)
        print("Uploading settings to db:", name, value)

    if verbose:
        print("[x] Added Dummy Settings")



from .models import Settings
from init import db


def set_setting(key, value):
    setting = Settings.query.filter(Settings.setting == key).first()
    if setting:
        setting.value = value
        setting.update()
    else:
        s = Settings(setting=key, value=value)
        s.add()
        s.update()


def get_setting(name):
    """
    Used as key-value lookup from Settings table

    Parameters
    ----------
    name: str
        name of key

    Returns
    -------
    str
        value of key
    """
    s = Settings.query.get(name)
    if s:
        return s.value
    return None



from typing import Any
import os
import json
from flask import Flask
from .upload import upload
from .helpers import get_setting

__version__ = "1.3.0"

info = {}
with open(os.path.dirname(os.path.abspath(__file__)) + os.sep + "info.json") as f:
    info = json.load(f)


class ShopyoSettings:
    def __init__(self, app: Any = None) -> None:
        if app is not None:
            self.init_app(app)
        self.upload = upload
        self.get_setting = get_setting

    def init_app(self, app: Flask) -> None:
        if not hasattr(app, "extensions"):
            app.extensions = {}

        app.extensions["shopyo_settings"] = self
        app.jinja_env.globals["shopyo_settings"] = self

    def get_info(self):
        return info
